@@ -1,10 +1,7 @@
 use super::{Distrib, QueryResult};
 
 pub(super) fn firefox_esr() -> QueryResult {
-    Ok(vec![
-        Distrib::new("firefox", "78"),
-        Distrib::new("firefox", "91"),
-    ])
+    Ok(vec![Distrib::new("firefox", "91")])
 }
 
 #[cfg(test)]
